What Not to Say to a Birth Mom or Adoptee | Adoption.com
Description: This is solely my opinion. Every person is different, so the things that I have experienced in no way reflect EVERY birth mother or adoptee. What Not to
Keywords: 7 Birth Parents, Adopt a Baby, Adoptee, Adoptee Community, Adoptee Stories, Adopting, Adoption Buzz, Adoptive Parent Community, Birth Family, Birth Family Community, Birth Family Stories, Birth Mother Stories, Birth Mother Stories, Community, Parent, Parenting & Adoption, Protecting Myself, Self-Improvement, Taking Care of Me, Why Adoption?

Navigation
Home/7 Birth Parents

# What Not to Say to a Birth Mom or Adoptee

## Choose your words wisely.

Share
Pin
Tweet
Share

This is solely my opinion. Every person is different, so the things that I have experienced in no way reflect EVERY birth mother or adoptee.

### What Not to Ask or Say to a Birth Mom

First, the biggest mistake I often hear in adoption talk is “giving a baby up for adoption.” I know this a common mistake. I’ve said it too, and I’m a birth mom AND an adoptee! This phrase is such a stab in the heart to most birth moms because it presumes we just gave our baby away because we did not want him or her. Giving something away typically means you did not want whatever it was. In the adoption world, we use the term “place.” I placed my birth son for adoption. This phrase is much more loving and just sounds better. We placed our baby in the arms of their parents. We placed them in a good home. Placing something somewhere is usually done with care and caution because you have love and concern for what you are placing. In the adoption world, placing our children is done with love and concern.

“Birth moms are just lazy.”

I know someone who used to have this notion about birth moms. He said he thought birth mother simply did not want the responsibility of taking care of a child. Being a birth mother is much more difficult than one might think. Choosing to be a birth mom is choosing an emotionally difficult path, a path far from lazy. I hope not many people think this, but if you do, do not say it to a birth mom. Go talk to one so she can change your mind!

“So, did you not want your baby?”

Yes, people actually ask this. I know for many people, they really cannot comprehend why I, or any other birth mother, would allow someone else to raise their child. The reasons are usually very personal. Every birth mom I have met all wanted their children, but for their personal and very emotional reasons, chose adoption for their baby.

“Do you think your birth son will be mad at you for choosing adoption?”

He might be mad. He might question why I did choose adoption. I also trust his parents. I trust that they will tell him how much I loved him and that I wanted him to have the very best life from the start. Will this ease his questioning? I do not know. I do know that it eased mine. I was never angry with my own birth mother because my parents always told me the great love she had for me. There was never a question or doubt of her love for me. I trust that my birth son will feel the same.

This question is hurtful, but it allows a birth mother to share her testimony of why she chose adoption. We can never determine what the future holds. A birth mom cannot determine the future effects that an adoption will have on a child.

“Can you get your baby back?”

I hate to think that people really do not understand what adoption is. Adoption is much different from foster care. In the foster care system, most children were taken out of the home due to the parents not doing what was best for their child. Yes, they can get their children back after they get things in order and clean up their life. However, adoption is different. An expectant parent chooses a family for their child and when that child is born, the birth mother then signs all parental rights away to the new parents. It varies by state, but usually the birth mother only has a limited amount of time to change her mind (in California it is 24 hours). I do not think this question is appropriate to ask any birth mother. The choice she made was not easy and a question like this may generate painful feelings.

### What Not to Ask or Say to an Adoptee

“Do you know your real parents?”

I love my birth mother and she is just that: my birth mother. My mom is the woman that raised me–my adoptive mother. So, to ask an adoptee if they know their real parents is thoughtless and can be hurtful. Many adoptees do not even know their birth parents. All they have ever known is their adoptive parents: their real parents.

“You know your birth mom didn’t love you.”

Someone once said this too me. It was someone who did not know me but knew I was adopted. I did not let this comment get to me because I knew without any doubt that my birth mom did love me. I knew because my parents had told me and my birth mother had written me a letter when I was just hours old. A comment like this is completely horrible and heartless. Yes, my birth mother loved me. That is why she chose life for me and gave me a wonderful family.

“All adopted kids are messed up.”

I have heard that my siblings and I are the exception to this rule because someone knows one family who has one adopted kid that has some problems. This must mean all adopted kids are messed up right? How many families do you know who have biological children who are “messed up”? I know plenty! Therefore, I do not think there is any merit to this comment. The child might have had problems if he or she was not adopted. Maybe their bad behavior is just their personality. If children are adopted at an older age and have experienced traumatic things, then yes, they may have some issues to be addressed. However, categorizing all adoptees into being “messed up” is wrong and hurtful.

These comments and questions are just a few of the things not to say to a birth mom or adoptee. I picked these particular comments and questions because they have been directed at me at some point. Just remember: When speaking to an adoptee or birth mom, it is okay to ask questions. I am an open book! However, be sensitive. I know many people are curious, but maybe the adoptee or birth mom is not ready to answer certain questions. Let certain things stay personal. If the adoptee or birth mom chooses to share, they will.

Love this? Want more?

Sign up for our newsletter and never miss out on the best adoption content!

Sign up for our newsletter!

#### AUTHOR / Sierra Kilpatrick

I had the privileged of being adopted as a newborn baby. I have a great relationship with my birth mom, who I met when I was 23. At 22, I had my own unplanned pregnancy and decided adoption was best for my birth son. I have spent the years since his birth in 2006, mentoring other birth moms and sharing my story. I hope to shed a positive light on adoption. I love both my roles as an adoptee and a birth mom. I met my prince charming and was married in 2007. In 2010, my husband and I welcomed a beautiful baby girl into our world.

### Comments

host: www1